PyHarmX — PyHarmX 0.1.0 documentation

# PyHarmX

Polyharmonic spline interpolation in PyTorch

PyHarmX is a PyTorch module designed for efficient polyharmonic spline interpolation. Leveraging GPU acceleration, this implementation excels in performance, making it well-suited for large-scale interpolation tasks.

If you are looking for information on a specific function, class or method, the API section of the documentation is for you.

Note

This project is under active development.

Contents

- Installation
- Explore
- License

API

- pyharmx.interpolator module
  - `PolyHarmInterpolator`
- pyharmx.functions module
  - `cross_squared_distance_matrix()`
  - `get_phi()`
  - `pairwise_squared_distance_matrix()`

## Indices and tables

- Index

- Module Index